[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Documents Distributor - CallStreet Events client library for Python

[![API Version](https://img.shields.io/badge/api-v1.8.3-blue)](https://developer.factset.com/api-catalog/documents-distributor-callstreet-events)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.DocumentsDistributorCallStreetEvents)](https://pypi.org/project/fds.sdk.DocumentsDistributorCallStreetEvents/)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

CallStreet Events contains all the Documents Distributor APIs that offer events data such as Events Audio and Near Real-Time Transcripts.

The  Events Audio API provides access to historical as well as the latest audio recordings of various company events covered by FactSet. The events include, but are not limited to: earnings calls, conferences, and investor days. 

This API also provides relevant metadata such as timestamps and identifiers around each audio file.

The Documents Distributor - Near Real-time Transcripts API enables access to Near Real-time Transcripts provided by CallStreet to time-sensitive clients. This API also provides the relevant speaker metadata along with their confidence scores. This data caters to quant clients interested in building machine learning models.

Clients can leverage this API to perform sentiment analysis through natural language processing or machine learning. It can also be used to complement analysis using FactSet's transcripts service.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.8.3
- SDK version: 0.21.19
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.DocumentsDistributorCallStreetEvents==0.21.19
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.DocumentsDistributorCallStreetEvents==0.21.19
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.DocumentsDistributorCallStreetEvents
from fds.sdk.DocumentsDistributorCallStreetEvents.api import events_audio_api
from fds.sdk.DocumentsDistributorCallStreetEvents.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.DocumentsDistributorCallStreetEvents.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.DocumentsDistributorCallStreetEvents.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.DocumentsDistributorCallStreetEvents.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = events_audio_api.EventsAudioApi(api_client)
    pagination_limit = 25 # int | Specifies the number of results to return per page. [ Min=0 ; Max=500 ] (optional) if omitted the server will use the default value of 25
    pagination_offset = 0 # int | Specifies the starting point for pagination. This parameter is used to identify the beginning of next set of results. (optional) if omitted the server will use the default value of 0
    year = 2021 # int | Specifies the year for which the historical audio recordings and related metadata are to be retrieved. (optional)
    trimmed = True # bool | Specifies if trimmed/untrimmed historical audio recordings should be returned. (optional) if omitted the server will use the default value of False

    try:
        # Retrieve historical audio recordings and related metadata within FactSet coverage.
        # example passing only required values which don't have defaults set
        # and optional values
        api_response = api_instance.get_docs_distributor_audio_v1_history_files(pagination_limit=pagination_limit, pagination_offset=pagination_offset, year=year, trimmed=trimmed)

        pprint(api_response)
    except fds.sdk.DocumentsDistributorCallStreetEvents.ApiException as e:
        print("Exception when calling EventsAudioApi->get_docs_distributor_audio_v1_history_files: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Retrieve historical audio recordings and related metadata within FactSet coverage.
    #     api_response, http_status_code, response_headers = api_instance.get_docs_distributor_audio_v1_history_files_with_http_info(pagination_limit=pagination_limit, pagination_offset=pagination_offset, year=year, trimmed=trimmed)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.DocumentsDistributorCallStreetEvents.ApiException as e:
    #     print("Exception when calling EventsAudioApi->get_docs_distributor_audio_v1_history_files: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Retrieve historical audio recordings and related metadata within FactSet coverage.
    #     async_result = api_instance.get_docs_distributor_audio_v1_history_files_async(pagination_limit=pagination_limit, pagination_offset=pagination_offset, year=year, trimmed=trimmed)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.DocumentsDistributorCallStreetEvents.ApiException as e:
    #     print("Exception when calling EventsAudioApi->get_docs_distributor_audio_v1_history_files: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Retrieve historical audio recordings and related metadata within FactSet coverage.
    #     async_result = api_instance.get_docs_distributor_audio_v1_history_files_with_http_info_async(pagination_limit=pagination_limit, pagination_offset=pagination_offset, year=year, trimmed=trimmed)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.DocumentsDistributorCallStreetEvents.ApiException as e:
    #     print("Exception when calling EventsAudioApi->get_docs_distributor_audio_v1_history_files: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.DocumentsDistributorCallStreetEvents

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.DocumentsDistributorCallStreetEvents.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.DocumentsDistributorCallStreetEvents

configuration = fds.sdk.DocumentsDistributorCallStreetEvents.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.DocumentsDistributorCallStreetEvents

configuration = fds.sdk.DocumentsDistributorCallStreetEvents.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.DocumentsDistributorCallStreetEvents

configuration = fds.sdk.DocumentsDistributorCallStreetEvents.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*EventsAudioApi* | [**get_docs_distributor_audio_v1_history_files**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioApi.md#get_docs_distributor_audio_v1_history_files) | **GET** /docs-distributor/audio/v1/history-files | Retrieve historical audio recordings and related metadata within FactSet coverage.
*EventsAudioApi* | [**get_docs_distributor_audio_v1_list_files**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioApi.md#get_docs_distributor_audio_v1_list_files) | **GET** /docs-distributor/audio/v1/list-files | Retrieve latest audio recordings and related metadata within FactSet coverage.
*NearRealTimeTranscriptsApi* | [**get_bulk_documents_nrt_v1_calls**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NearRealTimeTranscriptsApi.md#get_bulk_documents_nrt_v1_calls) | **GET** /bulk-documents/nrt/v1/calls | Returns the active calls happening at the moment.
*NearRealTimeTranscriptsApi* | [**get_bulk_documents_nrt_v1_indexed_nrt**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NearRealTimeTranscriptsApi.md#get_bulk_documents_nrt_v1_indexed_nrt) | **GET** /bulk-documents/nrt/v1/indexed-nrt | Returns the  indexed transcript data  in small increments throughout the duration of an active call.
*NearRealTimeTranscriptsApi* | [**get_bulk_documents_nrt_v1_list_snippets**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NearRealTimeTranscriptsApi.md#get_bulk_documents_nrt_v1_list_snippets) | **GET** /bulk-documents/nrt/v1/list-snippets | Returns the latest transcript snippets from an active call.
*NearRealTimeTranscriptsApi* | [**get_bulk_documents_nrt_v1_speakerids**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NearRealTimeTranscriptsApi.md#get_bulk_documents_nrt_v1_speakerids) | **GET** /bulk-documents/nrt/v1/speakerids | Returns the latest speakerIds with the confidence scores generated for an active call.


## Documentation For Models

 - [Error](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/Error.md)
 - [EventsAudio](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudio.md)
 - [EventsAudio400Response](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudio400Response.md)
 - [EventsAudio400ResponseDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudio400ResponseDetails.md)
 - [EventsAudio400ResponseDetailsValidParameters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudio400ResponseDetailsValidParameters.md)
 - [EventsAudioData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioData.md)
 - [EventsAudioHistory](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioHistory.md)
 - [EventsAudioHistory400Response](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioHistory400Response.md)
 - [EventsAudioHistory400ResponseDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioHistory400ResponseDetails.md)
 - [EventsAudioHistory400ResponseDetailsValidParameters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioHistory400ResponseDetailsValidParameters.md)
 - [EventsAudioHistoryData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioHistoryData.md)
 - [EventsAudioHistoryMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioHistoryMeta.md)
 - [EventsAudioMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioMeta.md)
 - [EventsAudioMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/EventsAudioMetaPagination.md)
 - [IndexedNRT](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/IndexedNRT.md)
 - [IndexedNRTMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/IndexedNRTMeta.md)
 - [IndexedNRTMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/IndexedNRTMetaPagination.md)
 - [NRTCalls](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTCalls.md)
 - [NRTCalls400Response](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTCalls400Response.md)
 - [NRTCalls400ResponseDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTCalls400ResponseDetails.md)
 - [NRTCalls400ResponseDetailsValidParameters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTCalls400ResponseDetailsValidParameters.md)
 - [NRTCallsData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTCallsData.md)
 - [NRTCallsMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTCallsMeta.md)
 - [NRTSnippets](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippets.md)
 - [NRTSnippets400Response](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippets400Response.md)
 - [NRTSnippets400ResponseDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippets400ResponseDetails.md)
 - [NRTSnippets400ResponseDetailsValidParameters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippets400ResponseDetailsValidParameters.md)
 - [NRTSnippetsData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippetsData.md)
 - [NRTSnippetsMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippetsMeta.md)
 - [NRTSnippetsMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippetsMetaPagination.md)
 - [NRTSnippetsMetaPartial](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippetsMetaPartial.md)
 - [NRTSnippetsSnippetData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippetsSnippetData.md)
 - [NRTSnippetsTranscriptData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSnippetsTranscriptData.md)
 - [NRTSpeakerids](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSpeakerids.md)
 - [NRTSpeakerids400Response](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSpeakerids400Response.md)
 - [NRTSpeakerids400ResponseDetails](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSpeakerids400ResponseDetails.md)
 - [NRTSpeakerids400ResponseDetailsValidParameters](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSpeakerids400ResponseDetailsValidParameters.md)
 - [NRTSpeakeridsData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSpeakeridsData.md)
 - [NRTSpeakeridsMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSpeakeridsMeta.md)
 - [NRTSpeakeridsMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/DocumentsDistributorCallStreetEvents/v1/docs/NRTSpeakeridsMetaPagination.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.DocumentsDistributorCallStreetEvents.apis and fds.sdk.DocumentsDistributorCallStreetEvents.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.DocumentsDistributorCallStreetEvents.api.default_api import DefaultApi`
- `from fds.sdk.DocumentsDistributorCallStreetEvents.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.DocumentsDistributorCallStreetEvents
from fds.sdk.DocumentsDistributorCallStreetEvents.apis import *
from fds.sdk.DocumentsDistributorCallStreetEvents.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2022 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

